@@ -38,6 +38,7 @@ class BaseInterfaceLine(BaseConfigLine):
     _channel_group_regex = re.compile(pattern=r"^ channel-group (?P<channel_group_number>\d+) mode (?P<channel_group_mode>\S+)")
     _speed_regex = re.compile(pattern=r"^ speed (?P<speed>\d+)", flags=re.MULTILINE)
     _duplex_regex = re.compile(pattern=r"^ duplex (?P<duplex>full|half)", flags=re.MULTILINE)
+    _load_interval_regex = re.compile(pattern=r"^ load-interval (?P<load_interval>\d+)")
 
     _bandwidth_regex = re.compile(pattern=r"^ bandwidth (?P<bandwidth>\d+)", flags=re.MULTILINE)
     _delay_regex = re.compile(pattern=r"^ delay (?P<delay>\d+)", flags=re.MULTILINE)
@@ -74,7 +75,7 @@ class BaseInterfaceLine(BaseConfigLine):
 
 
 
-    def __init__(self, number, text, config, verbosity=3):
+    def __init__(self, number, text, config, verbosity=3, name="BaseInterfaceLine"):
         """
         **This class is not meant to be instantiated directly, but only from BaseConfigParser instance.**
 
@@ -85,9 +86,7 @@ class BaseInterfaceLine(BaseConfigLine):
             verbosity (:obj:`int`, optional): Logging output level, defaults to 3: Warning
 
         """
-        super(BaseInterfaceLine, self).__init__(number=number, text=text, config=config, verbosity=verbosity)
-        self.logger = get_logger(name="BaseInterfaceLine", verbosity=verbosity)
-        self.logger.debug("Parsing interface line: '{}'".format(text))
+        super(BaseInterfaceLine, self).__init__(number=number, text=text, config=config, verbosity=verbosity, name=name)
 
     @functools.lru_cache()
     def get_unprocessed(self, return_type=None):
@@ -133,6 +132,7 @@ class BaseInterfaceLine(BaseConfigLine):
             self._channel_group_regex,
             self._speed_regex,
             self._duplex_regex,
+            self._load_interval_regex,
             self._bandwidth_regex,
             self._delay_regex,
             self._mtu_regex,
@@ -148,6 +148,12 @@ class BaseInterfaceLine(BaseConfigLine):
             self._storm_control_threshold_regex,
             self._storm_control_action_regex,
             self._encapsulation_regex,
+            self._service_instance_regex,
+            self._service_instance_description_regex,
+            self._service_instance_encapsulation_mapping_regex,
+            self._service_instance_encapsulation_string_regex,
+            self._service_instance_bridge_domain_regex,
+            self._service_instance_service_policy_regex,
             re.compile(pattern=r"^\sno\sip\saddress", flags=re.MULTILINE),
             re.compile(pattern=r"^ (no )?switchport$", flags=re.MULTILINE),
             re.compile(pattern=r"^ spanning-tree portfast")
@@ -808,6 +814,24 @@ class BaseInterfaceLine(BaseConfigLine):
             tcp_mss = int(candidates[0])
         return tcp_mss
 
+    @property
+    @functools.lru_cache()
+    def load_interval(self):
+        """
+        Return Load Interval of the interface set by command **load-interval X**.
+
+        Returns:
+            int: Load Interval
+
+            Returns ``None`` if absent
+
+        """
+        load_interval = None
+        candidates = self.re_search_children(regex=self._load_interval_regex, group="load_interval")
+        if len(candidates):
+            load_interval = int(candidates[0])
+        return load_interval
+
     @property
     @functools.lru_cache()
     def keepalive(self):
@@ -958,11 +982,7 @@ class BaseInterfaceLine(BaseConfigLine):
             device_tracking_policy = candidates[0]
         return device_tracking_policy
 
-
-
-
-    def __str__(self):
-        return "[BaseInterfaceLine #{} ({}): '{}']".format(self.number, self.type, self.text)
-
-    def __repr__(self):
-        return self.__str__()
+    @property
+    def ip_unnumbered_interface(self):
+        self.logger.warning("This object does not support this property.")
+        return None
